@@ -498,12 +498,6 @@ class H460_FeatureTable : public H225_ArrayOf_EnumeratedParameter
     */
     PBoolean ParameterIsUnique(const H460_FeatureID & id);
 
-    /** Operator
-    */
-    inline H460_FeatureParameter & operator[](
-      PINDEX id  ///* Index position in the collection of the object.
-    ) const { return operator[](id); };
-
     /** Operator
     */
     H460_FeatureParameter & operator[](
@@ -702,20 +696,12 @@ class H460_Feature : public H225_FeatureDescriptor
 
     /** Accessing the Parameters
     */
-    inline H460_FeatureParameter & operator()(
-      PINDEX id  //* Index position in the collection of the object.
-    ) const { return operator()(id); };
-
     H460_FeatureParameter & operator()(
       PINDEX id  ///* Index position in the collection of the object.
     );
 
     /** Accessing the Parameters
     */
-    inline H460_FeatureParameter & operator[](
-      const H460_FeatureID & id  //< FeatureID of the object.
-    ) const { return operator()(id); };
-
     H460_FeatureParameter & operator()(
       const H460_FeatureID & id  ///< FeatureID of the object.
     );
@@ -732,7 +718,7 @@ class H460_Feature : public H225_FeatureDescriptor
       */
     void SetCurrentTable(H460_FeatureTable & table);
 
-    /** Set the curernt Feature Table from Parameter
+    /** Set the current Feature Table from Parameter
       */
     void SetCurrentTable(H460_FeatureParameter & param);
 
@@ -766,8 +752,8 @@ class H460_Feature : public H225_FeatureDescriptor
       */
     static PStringArray GetFeatureFriendlyName() { return PStringArray("empty"); };
 
-    /** Get the purpose of the the Feature whether for Signalling,RAS or both. This determines
-        when the class is instantized
+    /** Get the purpose of the the Feature whether for Signalling, RAS or both. This determines
+        when the class is instantiated
       */
     static int GetPurpose()    { return FeatureBaseAll; };
 
@@ -989,12 +975,6 @@ class H460_FeatureNonStd : public H460_Feature
 
   //@}
 
-    /** Operator
-    */
-    inline H460_FeatureParameter & operator[](
-      PString id  ///* Index position in the collection of the object.
-    ) const { return operator[](id); };
-
     /** Operator
     */
     H460_FeatureParameter & operator[](
@@ -1048,12 +1028,6 @@ class H460_FeatureOID : public H460_Feature
 
   //@}
 
-    /** Operator
-    */
-    inline H460_FeatureParameter & operator[](
-      OpalOID id  ///* Index position in the collection of the object.
-    ) const { return operator[](id); };
-
     /** Operator
     */
     H460_FeatureParameter & operator[](
