@@ -34,7 +34,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Id: ptlib_extras.h,v 1.46 2014/04/23 22:27:03 shorne Exp $
+ * $Id$
  *
  */
 
@@ -796,7 +796,7 @@ protected:
 
 public:
     H323_FrameBuffer()
-    : PThread(10000, NoAutoDeleteThread, HighestPriority), m_threadRunning(false),
+    : PThread(10000, NoAutoDeleteThread, HighestPriority, "FrameBuffer"), m_threadRunning(false),
       m_frameMarker(0), m_frameOutput(false), m_frameStartTime(0), 
       m_StartTimeStamp(0), m_calcClockRate(90),
       m_packetReceived(0), m_oddTimeCount(0), m_lateThreshold(5.0), m_increaseBuffer(false),
